//
// Module: CrossRegionArf
// Author: Richard Saxton
//
// Description: 
//
// A class to find the effective area in a region caused by the PSF
// overflow from a second region
// Used for prototyping; will be eventually replaced by relevant CAL fn.
//
// Modifications: See ChangeLog
// 
// $Id: CrossRegionArf.h,v 1.1 2006/09/05 15:56:13 rsaxton Exp $

#ifndef CrossRegionArf_H
#define CrossRegionArf_H

/* SAS-specific */
#include "CalCommon.h"
#include "CalServer.h"

/* Local */
#include "CalPsfModel.h"
#include "DetmapFilter.h"
#include "PixelIterator.h"
#include "DatafileAttributes.h"
#include "DataSubspace.h"
#include "PositionUtils.h"


class CrossRegionArf
{
public:

  /* Constructor */
   CrossRegionArf(  string cr_spectrumsetName, // Name of 2nd spectrum
                    PixelIterator *rawDetmap, // Detector map from image
                    const PositionUtils * const putils);  // Position conversion object  

  /* Destructor */
  ~CrossRegionArf();

  /* Set up filtered detector map for the second region */
  PixelIterator * const  detmapPixelIterator();
  
  /* Calculate the product of mirror effective area and PSF spilling
     from one area to another at this position */
  EffectiveAreaCurve psfVignet( double theta, double phi );

private:

 /* Initialise detector map and PSF array */
  void init();
  
  PixelIterator * _rawDetmap;
  const PositionUtils * _putils;
  const DataSubspace * _crdss;
  DatafileAttributes   * _crspecAttributes;
  bool                 _init;
  PixelIterator        * _crfilteredDetmap;
  vector<CalPsfModel *>  _crPsf;
  vector<EffectiveAreaCurve> _eacurve;
  vector<double> _pixnorm;
  vector<double> _energyVector; 
  double _x_Width, _y_Width; 
};

#endif

